<?php
namespace bwdpsPhotoStack;

use bwdpsPhotoStack\PageSettings\Page_Settings;
define( "bwdps_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "bwdps_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Classbwdpsphotostack {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdps_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdps_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdps_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdps_photo_stack_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdps-photoStack.php' );
	}

	public function bwdps_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register WidgetsF
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\bwdps_photostack());
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdps-photostack-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdps_new_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdps-photostack-category',
			[
				'title' => esc_html__( 'Photo Stack', 'bwdps-Photo-Stack' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdps_all_assets_for_the_public(){
		$all_css_js_file = array(
            'bwdps_photostack_plugin_main_css' => array('bwdps_path_define'=>bwdps_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/main.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdps_path_define'], null, '1.3', 'all');
        }
	}

	public function bwdps_all_assets_for_the_public_animatemincss(){
		$all_css_js_file = array(
            'bwdps_photostack_plugin_animate_css' => array('bwdps_path_define'=>bwdps_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/animate.min.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdps_path_define'], null, '1.3', 'all');
        }
	}

	public function bwdps_all_assets_for_the_public_responsivess(){
		$all_css_js_file = array(
            'bwdps_photostack_plugin_responsive_css' => array('bwdps_path_define'=>bwdps_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/responsive.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdps_path_define'], null, '1.3', 'all');
        }
	}

	public function bwdps_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdps_photostack_admin_icon_css' => array('bwdps_path_admin_define'=>bwdps_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdps_path_admin_define'], null, '1.3', 'all');
        }
	}

	function bwdps_photo_stack_register_required_plugins() {
		$plugins = array(
			array(
				'name'        => esc_html__('Elementor', 'bwdps-Photo-Stack'),
				'slug'        => 'elementor',
				'is_callable' => 'wpseo_init',
			),
	
		);

		$config = array(
			'id'           => 'bwdps-photo-stack',
			'default_path' => '',
			'menu'         => 'tgmpa-install-plugins',
			'parent_slug'  => 'plugins.php',
			'capability'   => 'manage_options',
			'has_notices'  => true,
			'dismissable'  => true,
			'dismiss_msg'  => '',
			'is_automatic' => false,
			'message'      => '',
		);
	
		tgmpa( $plugins, $config );
	}
	
	public function __construct() {
		// For tgm plugin activation
		add_action( 'tgmpa_register', [$this, 'bwdps_photo_stack_register_required_plugins'] );

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdps_all_assets_for_the_public']);

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdps_all_assets_for_the_public_animatemincss']);

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdps_all_assets_for_the_public_responsivess']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdps_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdps_new_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdps_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdps_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
Classbwdpsphotostack::instance();